@@ -15,7 +15,6 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 import os
 from contextlib import closing
 from copy import deepcopy
@@ -57,7 +56,6 @@ class PostgresHook(DbApiHook):
 
     :param postgres_conn_id: The :ref:`postgres conn id <howto/connection:postgres>`
         reference to a specific postgres database.
-    :type postgres_conn_id: str
     """
 
     conn_name_attr = 'postgres_conn_id'
@@ -140,7 +138,7 @@ class PostgresHook(DbApiHook):
 
     def get_uri(self) -> str:
         conn = self.get_connection(getattr(self, self.conn_name_attr))
-        uri = super().get_uri()
+        uri = super().get_uri().replace("postgres://", "postgresql://")
         if conn.extra_dejson.get('client_encoding', False):
             charset = conn.extra_dejson["client_encoding"]
             return f"{uri}?client_encoding={charset}"
@@ -164,9 +162,7 @@ class PostgresHook(DbApiHook):
         more information.
 
         :param cell: The cell to insert into the table
-        :type cell: object
         :param conn: The database connection
-        :type conn: connection object
         :return: The cell
         :rtype: object
         """
@@ -192,7 +188,7 @@ class PostgresHook(DbApiHook):
             # Pull the custer-identifier from the beginning of the Redshift URL
             # ex. my-cluster.ccdre4hpd39h.us-east-1.redshift.amazonaws.com returns my-cluster
             cluster_identifier = conn.extra_dejson.get('cluster-identifier', conn.host.split('.')[0])
-            session, endpoint_url = aws_hook._get_credentials()
+            session, endpoint_url = aws_hook._get_credentials(region_name=None)
             client = session.client(
                 "redshift",
                 endpoint_url=endpoint_url,
@@ -211,14 +207,12 @@ class PostgresHook(DbApiHook):
             token = aws_hook.conn.generate_db_auth_token(conn.host, port, conn.login)
         return login, token, port
 
-    def get_table_primary_key(self, table: str, schema: Optional[str] = "public") -> List[str]:
+    def get_table_primary_key(self, table: str, schema: Optional[str] = "public") -> Optional[List[str]]:
         """
         Helper method that returns the table primary key
 
         :param table: Name of the target table
-        :type table: str
-        :param table: Name of the target schema, public by default
-        :type table: str
+        :param schema: Name of the target schema, public by default
         :return: Primary key columns list
         :rtype: List[str]
         """
@@ -245,16 +239,11 @@ class PostgresHook(DbApiHook):
         The REPLACE variant is specific to PostgreSQL syntax.
 
         :param table: Name of the target table
-        :type table: str
         :param values: The row to insert into the table
-        :type values: tuple of cell values
         :param target_fields: The names of the columns to fill in the table
-        :type target_fields: iterable of strings
         :param replace: Whether to replace instead of insert
-        :type replace: bool
         :param replace_index: the column or list of column names to act as
             index for the ON CONFLICT clause
-        :type replace_index: str or list
         :return: The generated INSERT or REPLACE SQL statement
         :rtype: str
         """
